@@ -1,4 +1,4 @@
-/* $Id: tdb.c 25261 2007-03-23 01:53:16Z jannis $ */
+/* $Id$ */
 /*-
  * Copyright (c) 1999-2004 Andrew Tridgell <tridge@linuxcare.com>
  * Copyright (c) 2000      Paul `Rusty' Russel <rusty@linuxcare.com>
@@ -368,7 +368,7 @@ static int tdb_oob(TDB_CONTEXT *tdb, tdb_off len, int probe)
 	if (fstat(tdb->fd, &st) == -1)
 		return TDB_ERRCODE(TDB_ERR_IO, -1);
 
-	if (st.st_size < (size_t)len) {
+	if (st.st_size < (off_t)len) {
 		if (!probe) {
 			/* Ensure ecode is set for log fn. */
 			tdb->ecode = TDB_ERR_IO;
@@ -577,7 +577,7 @@ static int tdb_dump_chain(TDB_CONTEXT *tdb, int i)
 
 void tdb_dump_all(TDB_CONTEXT *tdb)
 {
-	int i;
+	unsigned int i;
 	for (i=0;i<tdb->header.hash_size;i++) {
 		tdb_dump_chain(tdb, i);
 	}
@@ -745,7 +745,7 @@ update:
 static int expand_file(TDB_CONTEXT *tdb, tdb_off size, tdb_off addition)
 {
 	char buf[1024];
-#if HAVE_FTRUNCATE_EXTEND
+#ifdef HAVE_FTRUNCATE_EXTEND
 	if (ftruncate(tdb->fd, size+addition) != 0) {
 		TDB_LOG((tdb, 0, "expand_file ftruncate to %d failed (%s)\n", 
 			   size+addition, strerror(errno)));
